<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\WhyChoose;
use Illuminate\Http\Request;
use Illuminate\Support\Str;
use Illuminate\Validation\Rule;
use Carbon\Carbon;
use Image;

class WhyChooseController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index()
    {
        return view('admin.why_choose', [
            'why_chooses' => WhyChoose::get(),
        ]);
    }

    public function why_choose_add()
    {
        return view('admin.why_choose_add');
    }

    public function insert(Request $request)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $request->validate([
            'photo' => 'required|file|image',
            'heading' => 'required',
            'full_content' => 'required'
        ]);

        if ($request->hasFile('photo')) {
            $file = $request->file('photo');
            $ext = $file->getClientOriginalExtension();
            $filename1 = 'why_choose_'.md5(mt_rand(11111111,99999999)).'.'.$ext;
            $file->move(public_path('uploads'),$filename1);
        }

        WhyChoose::create([
            'photo' => $filename1,
            'heading' => $request->heading,
            'full_content' => $request->full_content
        ]);

        return Redirect()->route('admin.why_choose')->with('success', A_SUCCESS_DATA_ADD);
    }

    public function edit_page($id)
    {
        return view('admin.why_choose_edit', [
            'why_choose' => WhyChoose::find($id),
        ]);
    }

    public function edit(Request $request)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $id = $request->id;

        $request->validate([
            'heading' => 'required',
            'full_content' => 'required'
        ]);

        $why_choose = WhyChoose::findOrFail($id);

        if ($request->hasFile('photo')) {
            $request->validate([
                'photo' => 'image'
            ]);
            $file = $request->file('photo');
            $ext = $file->getClientOriginalExtension();
            @unlink(public_path('uploads/'.$why_choose->photo));
            $filename1 = 'why_choose_'.md5(mt_rand(11111111,99999999)).'.'.$ext;
            $file->move(public_path('uploads'),$filename1);
            $why_choose->photo = $filename1;
        }

        $why_choose->heading = $request->heading;
        $why_choose->full_content = $request->full_content;
        $why_choose->update();

        return Redirect()->route('admin.why_choose')->with('success', A_SUCCESS_DATA_UPDATE);
    }

    public function delete($id)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }
        
        $photo = WhyChoose::find($id)->photo;
        unlink(public_path('uploads/' . $photo));
        WhyChoose::find($id)->forceDelete();
        return Redirect()->route('admin.why_choose')->with('success', A_SUCCESS_DATA_DELETE);
    }
}
